Crate mapstic_core

Crate mapstic_core 

Core types and functionality used by the code generated by the mapstic-derive crate.

Structs

Object
A complex object within an Elasticsearch mapping.
Params
Collection of field mapping parameters.
Property
A scalar field within an Elasticsearch mapping.

Enums

Mapping
An Elasticsearch field mapping.
ParamValue
A value for a specific field mapping option.

Traits

ToMapping
A type that can be described as an explicit Elasticsearch mapping.

Functions

default_string_options
Default options to be applied to string types.