Mapping

Enum Mapping 

pub enum Mapping {
    // some variants omitted
}
An Elasticsearch field mapping.

Generally speaking, this will be serialised and sent to Elasticsearch via the update mapping API. The default serde_json representation of this type is a valid request body for that API.

To use this with the elasticsearch crate:

use elasticsearch::{http::transport::Transport, indices::IndicesPutMappingParts, Elasticsearch};
use mapstic::ToMapping;

#[derive(ToMapping)]
struct MyIndex {
    id: i64,
}

#[tokio::main]
async fn main() -> anyhow::Result<()> {
    let client = Elasticsearch::new(Transport::single_node("http://localhost:9200")?);
    let response = client
        .indices()
        .put_mapping(IndicesPutMappingParts::Index(&["my-index"]))
        .body(MyIndex::to_mapping())
        .send()
        .await?;

    dbg!(response);
    Ok(())
}