pub fn default_string_options() -> ParamsExpand description
Default options to be applied to string types.
These match the defaults when a string is dynamically mapped by Elasticsearch.
pub fn default_string_options() -> ParamsDefault options to be applied to string types.
These match the defaults when a string is dynamically mapped by Elasticsearch.