pub trait ToMapping {
// Provided method
fn to_mapping() -> Mapping { ... }
}Expand description
A type that can be described as an explicit Elasticsearch mapping.
This trait must be derived, rather than being implemented directly onto a type.
Provided Methods
Sourcefn to_mapping() -> Mapping
fn to_mapping() -> Mapping
Returns the Elasticsearch mapping for the type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.